@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indická rupie',
     'JPY - Japanese Yen' => 'JPY - Japonský jen',
     'NZD - New Zealand Dollar' => 'NZD - Novozélandský dolar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Srbský dinár',
     'CNY - Chinese Yuan' => 'CNY - čínský jüan',
     'USD - US Dollar' => 'USD - Americký dolar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Všechny úkoly ve sloupci "%s" a dráze "%s" byly úspěšně uzavřeny.',
     'Do you really want to close all tasks of this column?' => 'Opravdu chcete zavřít všechny úkoly tohoto sloupce?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d úkol(y) ve sloupci "%s" a dráha "%s" bude uzavřena.',
-    'Close all tasks of this column' => 'Uzavřít všechny úkoly v tomto sloupci',
+    'Close all tasks in this column and this swimlane' => 'Uzavřít všechny úkoly v tomto sloupci',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Žádný plugin není registrován na metodu oznamování projektu. Stále můžete konfigurovat jednotlivá oznámení v profilu uživatele.',
     'My dashboard' => 'Moje nástěnka',
     'My profile' => 'Můj profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Vybrat vše',
     'Unselect All' => 'Odznačit vše',
     'Apply action' => 'Použít akci',
-    'Move selected tasks to another column' => 'Přesuňte vybrané úkoly do jiného sloupce',
+    'Move selected tasks to another column or swimlane' => 'Přesuňte vybrané úkoly do jiného sloupce',
     'Edit tasks in bulk' => 'Úlohy lze upravovat hromadně',
     'Choose the properties that you would like to change for the selected tasks.' => 'Vyberte vlastnosti, které chcete změnit pro vybrané úkoly.',
     'Configure this project' => 'Nakonfigurovat tento projekt',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Změnit pořadí tohoto sloupce podle zadavatele (Z-A)',
     'Reorder this column by due date (ASC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (vzestupně)',
     'Reorder this column by due date (DESC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (sestupně)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s přesunul úkol #%d "%s" do projektu "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Úkol #%d "%s" byl přesunut do projektu "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pokud je datum vypršení platnosti menší než určitý počet dní, přesuňte úlohu do jiného sloupce',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
