@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - indisk rupee',
     'JPY - Japanese Yen' => 'JPY - japansk yen',
     'NZD - New Zealand Dollar' => 'NZD - new zealandsk dollar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - serbisk dinar',
     'CNY - Chinese Yuan' => 'CNY - kinesisk yuan',
     'USD - US Dollar' => 'USD - amerikansk dollar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle opgaver i kolonne "%s" og spor "%s" blev lukket.',
     'Do you really want to close all tasks of this column?' => 'Lukke alle opgaver i kolonnen?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d opgave(r) i kolonne "%s" og spor "%s" lukkes.',
-    'Close all tasks of this column' => 'Lukke alle opgaver i kolonne',
+    'Close all tasks in this column and this swimlane' => 'Lukke alle opgaver i kolonne',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Ingen udvidelses-modul har registreret projekt påmindelses-metode Brugeren kan stadig konfigurere individuelle påmindelser i brugerprofil.',
     'My dashboard' => 'Instrumentbræt',
     'My profile' => 'Profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Vælge alle',
     'Unselect All' => 'Fravælge alle',
     'Apply action' => 'Anvende handling',
-    'Move selected tasks to another column' => 'Flyt valgte opgaver til anden kolonne',
+    'Move selected tasks to another column or swimlane' => 'Flyt valgte opgaver til anden kolonne',
     'Edit tasks in bulk' => 'Masse redigere opgaver',
     'Choose the properties that you would like to change for the selected tasks.' => 'Vælg egenskaber som skal ændres for de valgte opgaver.',
     'Configure this project' => 'Indstille projekt',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Sorter kolonne efter ansvarlig (Z-A)',
     'Reorder this column by due date (ASC)' => 'Sorter kolonne efter udløbstid (ASC)',
     'Reorder this column by due date (DESC)' => 'Sorter kolonne efter udløbstid (DESC)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s flyttet opgave #%d "%s" til projekt "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Opgave #%d "%s" er flyttet til projekt "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Flyt opgave til anden kolonne når afleveringsdato er mindre end et bestemt antal dage',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
