@@ -388,7 +388,7 @@ return array(
     'Add' => 'Hinzufügen',
     'Start date' => 'Startdatum',
     'Time estimated' => 'Geschätzte Zeit',
-    'There is nothing assigned to you.' => 'Ihnen ist nichts zugewiesen.',
+    'There is nothing assigned to you.' => 'Dir ist nichts zugewiesen.',
     'My tasks' => 'Meine Aufgaben',
     'Activity stream' => 'Letzte Aktivitäten',
     'Dashboard' => 'Dashboard',
@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indische Rupien',
     'JPY - Japanese Yen' => 'JPY - Japanische Yen',
     'NZD - New Zealand Dollar' => 'NZD - Neuseeland-Dollar',
+    'PEN - Peruvian Sol' => 'PEN - Peruanischer Sol',
     'RSD - Serbian dinar' => 'RSD - Serbische Dinar',
     'CNY - Chinese Yuan' => 'CNY - Chinesische Renminbi',
     'USD - US Dollar' => 'USD - US-Dollar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle Aufgaben der Spalte "%s" und der Swimlane "%s" wurden erfolgreich geschlossen',
     'Do you really want to close all tasks of this column?' => 'Willst du wirklich alle Aufgaben in dieser Spalte schließen?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d Aufgabe(n) in der Spalte "%s" und in der Swimlane "%s" werden geschlossen.',
-    'Close all tasks of this column' => 'Alle Aufgaben in dieser Spalte schließen',
+    'Close all tasks in this column and this swimlane' => 'Alle Aufgaben in dieser Spalte schließen',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Kein Plugin hat eine Projekt-Benachrichtigungsmethode registriert. Du kannst individuelle Meldungen in deinem Benutzerprofil konfigurieren',
     'My dashboard' => 'Mein Dashboard',
     'My profile' => 'Mein Profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Alle auswählen',
     'Unselect All' => 'Keine auswählen',
     'Apply action' => 'Aktion anwenden',
-    'Move selected tasks to another column' => 'Ausgewählte Aufgaben in andere Spalte verschieben',
+    'Move selected tasks to another column or swimlane' => 'Ausgewählte Aufgaben in andere Spalte verschieben',
     'Edit tasks in bulk' => 'Massenbearbeitung',
     'Choose the properties that you would like to change for the selected tasks.' => 'Wähle die Eigenschaften aus, die du für die ausgewählten Aufgaben ändern möchtest.',
     'Configure this project' => 'Projekteinstellungen',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Spalte nach Zuständigem ordnen (Z-A)',
     'Reorder this column by due date (ASC)' => 'Spalte nach Fälligkeitsdatum ordnen (aufsteigend)',
     'Reorder this column by due date (DESC)' => 'Spalte nach Fälligkeitsdatum ordnen (absteigend)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s hat die Aufgabe #%d "%s" in das Projekt "%s" verschoben',
     'Task #%d "%s" has been moved to the project "%s"' => 'Aufgabe #%d "%s" wurde in das Projekt "%s" verschoben',
     'Move the task to another column when the due date is less than a certain number of days' => 'Verschieben der Aufgabe in eine andere Spalte, wenn die Fälligkeit kleiner als eine bestimmte Anzahl von Tagen ist',
@@ -1434,4 +1437,33 @@ return array(
     'Copy' => 'Kopieren',
     'Tasks copied successfully.' => 'Die Aufgaben wurden erfolgreich kopiert.',
     'Unable to copy tasks.' => 'Die Aufgaben konnten nicht kopiert werden.',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    'Just add these tag(s)' => 'Schlagwort(e) nur hinzufügen (bereits zugeordnete nicht löschen)',
+    'Remove internal link(s)' => 'Interne Verbindung(en) entfernen',
 );
