@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupia india',
     'JPY - Japanese Yen' => 'JPY - Yen japonés',
     'NZD - New Zealand Dollar' => 'NZD - Dólar de Nueva Zelanda',
+    'PEN - Peruvian Sol' => 'PEN - Sol peruano',
     'RSD - Serbian dinar' => 'RSD - Dinar serbio',
     'CNY - Chinese Yuan' => 'CNY - Yuan Chino',
     'USD - US Dollar' => 'USD - Dólar estadounidense',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas las tareas de la columna "%s" y el carril "%s" han sido cerradas con éxito.',
     'Do you really want to close all tasks of this column?' => '¿Realmente desea cerrar todas las tareas de esta columna?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarea(s) en la columna "%s" y el carril "%s" se cerrará.',
-    'Close all tasks of this column' => 'Cierre todas las tareas de esta columna',
+    'Close all tasks in this column and this swimlane' => 'Cierre todas las tareas de esta columna',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Ningún plugin ha registrado un método de notificación de proyecto. Todavía puede configurar notificaciones individuales en su perfil de usuario(a).',
     'My dashboard' => 'Mi tablero',
     'My profile' => 'Mi perfil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Seleccionar todo',
     'Unselect All' => 'Deseleccionar todo',
     'Apply action' => 'Aplicar acción',
-    'Move selected tasks to another column' => 'Mover tareas seleccionadas a otra columna',
+    'Move selected tasks to another column or swimlane' => 'Mover tareas seleccionadas a otra columna',
     'Edit tasks in bulk' => 'Editar tareas en masa',
     'Choose the properties that you would like to change for the selected tasks.' => 'Elija las propiedades que le gustaría cambiar para las tareas seleccionadas.',
     'Configure this project' => 'Configurar este proyecto',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta columna por persona asignada (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta columna por fecha de vencimiento (ASC)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta columna por fecha de vencimiento (DESC)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s movió la tarea #%d "%s" al proyecto "%s',
     'Task #%d "%s" has been moved to the project "%s"' => 'La tarea #%d "%s" se movió al proyecto "%s',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mueva la tarea a otra columna cuando la fecha de vencimiento sea inferior a un cierto número de días',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
