@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indijski rupi',
     'JPY - Japanese Yen' => 'JPY - Japanski yen',
     'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Srpski dinar',
     'CNY - Chinese Yuan' => 'CNY - Kineski jen',
     'USD - US Dollar' => 'USD - Američki dolar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Svi zadaci stupca "%s" i staze "%s" su uspješno zatvoreni.',
     'Do you really want to close all tasks of this column?' => 'Doista želite zatvoriti sve zadatke ovog stupca?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadatak/a u stupcu "%s" i stazi "%s" će biti zatvoreno.',
-    'Close all tasks of this column' => 'Zatvori sve zadatke ovog stupca',
+    'Close all tasks in this column and this swimlane' => 'Zatvori sve zadatke ovog stupca',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Niti jedan dodatak nije registrirao metodu za obavijesti o projektu. U korisničkom profilu i dalje možete urediti pojedinačne obavijesti.',
     'My dashboard' => 'Moja nadzorna ploča',
     'My profile' => 'Moj profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Označi sve',
     'Unselect All' => 'Poništi odabir svega',
     'Apply action' => 'Primjeni radnju',
-    'Move selected tasks to another column' => 'Pomakni odabrani zadatak u neki drugi stupac',
+    'Move selected tasks to another column or swimlane' => 'Pomakni odabrani zadatak u neki drugi stupac',
     'Edit tasks in bulk' => 'Masovno uređivanje zadataka',
     'Choose the properties that you would like to change for the selected tasks.' => 'Izaberite svojstva koja želite promijeniti na izabranim zadacima.',
     'Configure this project' => 'Uredite ovaj projekt',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Presloži ovaj stupac po izvršitelju (Ž-A)',
     'Reorder this column by due date (ASC)' => 'Presloži ovaj stupac po roku završetka (UZLAZNO)',
     'Reorder this column by due date (DESC)' => 'Presloži ovaj stupac po roku završetka (SILAZNO)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s je premjestio/la zadatak #%d "%s" u projekt "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premješten u projekt "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pomakni zadatak u drugi stupac kada je datum roka završetka kraći od određenog broja dana',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
