@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupe India',
     'JPY - Japanese Yen' => 'JPY - Yen Jepang',
     'NZD - New Zealand Dollar' => 'NZD - Dolar Selandia baru',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Dinar Serbia',
     // 'CNY - Chinese Yuan' => '',
     'USD - US Dollar' => 'USD - Dolar Amerika',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Semua tugas dalam kolom "%s" dan swimlane "%s" telah berhasil ditutup',
     'Do you really want to close all tasks of this column?' => 'Apakah Anda yakin mau menutup semua tugas dalam kolom ini?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tugas dalam kolom "%s" dan swimlane "%s" akan ditutup.',
-    'Close all tasks of this column' => 'Tutup semua tugas dalam kolom ini',
+    'Close all tasks in this column and this swimlane' => 'Tutup semua tugas dalam kolom ini',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Tidak ada plugin yang mendaftarkan metode pemberitahuan proyek. Anda masih bisa mengatur pemberitahuan individu di dalam profil pengguna Anda.',
     'My dashboard' => 'Dasbor saya',
     'My profile' => 'Profil saya',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Pilih Semua',
     'Unselect All' => 'Batal Pilih Semua',
     'Apply action' => 'Terapkan tindakan',
-    'Move selected tasks to another column' => 'Pindahkan tugas yang dipilih ke kolom lain',
+    'Move selected tasks to another column or swimlane' => 'Pindahkan tugas yang dipilih ke kolom lain',
     'Edit tasks in bulk' => 'Edit tugas secara massal',
     'Choose the properties that you would like to change for the selected tasks.' => 'Pilih properti yang ingin Anda ubah untuk tugas yang dipilih.',
     'Configure this project' => 'Konfigurasi proyek ini',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Susun ulang kolom ini oleh penerima tugas (Z-A)',
     'Reorder this column by due date (ASC)' => 'Susun ulang kolom ini sebelum tanggal jatuh tempo (ASC)',
     'Reorder this column by due date (DESC)' => 'Susun ulang kolom ini berdasarkan tanggal jatuh tempo (DESC)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s memindahkan tugas #%d "%s" ke proyek "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Task #%d "%s" telah dipindahkan ke proyek "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pindahkan tugas ke kolom lain ketika batas waktu kurang dari jumlah hari tertentu',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
