@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupie Indiani',
     'JPY - Japanese Yen' => 'JPY - Yen Giapponesi',
     'NZD - New Zealand Dollar' => 'NZD - Dollari della Nuova Zelanda',
+    'PEN - Peruvian Sol' => 'PEN - Sol Peruviano',
     'RSD - Serbian dinar' => 'RSD - Dinar Serbi',
     'CNY - Chinese Yuan' => 'CNY - Yuan Cinese',
     'USD - US Dollar' => 'USD - Dollari Americani',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Tutti i compiti della colonna "%s" e della corsia "%s" sono stati chiusi con successo.',
     'Do you really want to close all tasks of this column?' => 'Vuoi davvero chiudere tutti i compiti di questa colonna?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d compito/i della colonna "%s" e della corsia "%s" saranno chiusi.',
-    'Close all tasks of this column' => 'Chiudi tutti i compiti di questa colonna',
+    'Close all tasks in this column and this swimlane' => 'Chiudi tutti i compiti di questa colonna',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nessun plugin ha caricato un metodo di notifica di progetto. Puoi tuttavia configurare le notifiche personali dal tuo profilo utente.',
     'My dashboard' => 'La mia bacheca',
     'My profile' => 'Il mio profilo',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Seleziona tutti',
     'Unselect All' => 'Deseleziona tutti',
     'Apply action' => 'Applica azione',
-    'Move selected tasks to another column' => 'Sposta i compiti selezionati in un\'altra colonna',
+    'Move selected tasks to another column or swimlane' => 'Sposta i compiti selezionati in un\'altra colonna',
     'Edit tasks in bulk' => 'Modifica i compiti massivamente',
     'Choose the properties that you would like to change for the selected tasks.' => 'Scegli le proprietà che vorresti modificare per i compiti selezionato.',
     'Configure this project' => 'Configura questo progetto',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Ordina questa colonna per assegnatario (DESC)',
     'Reorder this column by due date (ASC)' => 'Riordina questa colonna per dat di scadenza (ASCENDENTE)',
     'Reorder this column by due date (DESC)' => 'Riordina questa colonna per dat di scadenza (DISCENDENTE)',
+    'Reorder this column by id (ASC)' => 'Riordina questa colonna per ID (ASC)',
+    'Reorder this column by id (DESC)' => 'Riordina questa colonna per ID (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s ha spostato il compito #%d "%s" al progetto "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Il compito #%d "%s"è stato spostato al progetto "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Sposta il compito ad un\'altra colonna se la dat di scadenza è più vicina di un certo numero di giorni',
@@ -1428,10 +1431,39 @@ return array(
     'You must select a file to upload as your avatar!' => 'Devi selezionare un file da caricare come avatar',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Il documento che hai caricato non è un\'immagine valida! (Sono permesse solo *.gif, *.jpg, *.jpeg and *.png)',
     'Automatically set the due date when the task is moved away from a specific column' => 'Imposta automaticamente la data di scadenza quando il compito viene spostato ad una colonna specifica',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
+    'No other projects found.' => 'Nessun altro progetto trovato.',
+    'Please choose a project you want to copy the tasks from.' => 'Per favore, scegli un progetto da cui copiare le attività.',
+    'Import Tasks' => 'Importa attività',
+    'Copy' => 'Copia',
+    'Tasks copied successfully.' => 'Attività copiate con successo.',
+    'Unable to copy tasks.' => 'Impossibile copiare le attività.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Tema chiaro',
+    'Dark theme' => 'Tema scuro',
+    'Automatic theme - Sync with system' => 'Tema automatico - Sincronizza con il sistema',
+    'Application managers or more' => 'Manager o altro',
+    'Administrators' => 'Amministratori',
+    'Visibility:' => 'Visibilità:',
+    'Standard users' => 'Utenti standard',
+    'Visibility is required' => 'La visibilità è richiesta',
+    'The visibility should be an app role' => 'La visibilità dovrebbe essere un ruolo dell\'app',
+    'Reply' => 'Rispondi',
+    '%s wrote: ' => '%s ha scritto',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
