@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - 인도 루피',
     'JPY - Japanese Yen' => 'JPY - 일본 엔',
     'NZD - New Zealand Dollar' => 'NZD - 뉴질랜드 달러',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - 세르비아 디나르',
     // 'CNY - Chinese Yuan' => '',
     'USD - US Dollar' => 'USD - 미국 달러',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '컬럼 "%s"와 스웜라인 "%s"의 모든 할일이 성공적으로 종료되었습니다',
     'Do you really want to close all tasks of this column?' => '이 컬럼의 모든 할일을 종료 하시겠습니까?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '컬럼 "%s"와 스웜라인 "%s"의 할일 %d가 종료될 것입니다',
-    'Close all tasks of this column' => '컬럼의 모든 할일 마치기',
+    'Close all tasks in this column and this swimlane' => '컬럼의 모든 할일 마치기',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '프로젝트 알림 방법으로 플러그인이 등록되지 않았습니다. 각각의 알림을 프로파일에서 설정하실 수 있습니다',
     'My dashboard' => '대시보드',
     'My profile' => '프로필',
@@ -1377,7 +1378,7 @@ return array(
     // 'Select All' => '',
     // 'Unselect All' => '',
     // 'Apply action' => '',
-    // 'Move selected tasks to another column' => '',
+    // 'Move selected tasks to another column or swimlane' => '',
     // 'Edit tasks in bulk' => '',
     // 'Choose the properties that you would like to change for the selected tasks.' => '',
     // 'Configure this project' => '',
@@ -1399,6 +1400,8 @@ return array(
     // 'Reorder this column by assignee (Z-A)' => '',
     // 'Reorder this column by due date (ASC)' => '',
     // 'Reorder this column by due date (DESC)' => '',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     // '%s moved the task #%d "%s" to the project "%s"' => '',
     // 'Task #%d "%s" has been moved to the project "%s"' => '',
     // 'Move the task to another column when the due date is less than a certain number of days' => '',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
