@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indiske rupi',
     'JPY - Japanese Yen' => 'JPY - Japanske yen',
     'NZD - New Zealand Dollar' => 'NZD - New Zealand Dollar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Serbiske dinarer',
     'CNY - Chinese Yuan' => 'CNY - Kinesiske yuan',
     'USD - US Dollar' => 'USD - Amerikanske dollar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle oppgaver i kolonne "%s" og svømmebane "%s" er lukket.',
     'Do you really want to close all tasks of this column?' => 'Ønsker du virkelig å lukke ALLE saker i kolonnen?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d oppgave(r) i kolonne "%s" og svømmebane "%s" vil bli lukket.',
-    'Close all tasks of this column' => 'Lukk alle saker i denne kolonnen',
+    'Close all tasks in this column and this swimlane' => 'Lukk alle saker i denne kolonnen',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Det finnes ingen innstikk for prosjektvarsling. Du kan likevel sette opp individuelle varslinger i brukerprofilen din.',
     'My dashboard' => 'Mitt dashbord',
     'My profile' => 'Min profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Velg alle',
     'Unselect All' => 'Fravelg alle',
     'Apply action' => 'Utfør',
-    'Move selected tasks to another column' => 'Flytt merkede oppgaver til en annen kolonne',
+    'Move selected tasks to another column or swimlane' => 'Flytt merkede oppgaver til en annen kolonne',
     'Edit tasks in bulk' => 'Masseredigering av oppgaver',
     'Choose the properties that you would like to change for the selected tasks.' => 'Velg egenskapene du vil endre for valgte oppgaver.',
     'Configure this project' => 'Prosjekt',
@@ -1399,6 +1400,8 @@ return array(
     // 'Reorder this column by assignee (Z-A)' => '',
     // 'Reorder this column by due date (ASC)' => '',
     // 'Reorder this column by due date (DESC)' => '',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     // '%s moved the task #%d "%s" to the project "%s"' => '',
     // 'Task #%d "%s" has been moved to the project "%s"' => '',
     // 'Move the task to another column when the due date is less than a certain number of days' => '',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
