@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupia indyjska',
     'JPY - Japanese Yen' => 'JPY - Jen japoński',
     'NZD - New Zealand Dollar' => 'NZD - Dolar nowozelandzki',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Dinar serbski',
     'CNY - Chinese Yuan' => 'CNY - Juan chiński',
     'USD - US Dollar' => 'USD - Dolar amerykański',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Wszystkie zadania z kolumny "%s" i toru "%s" zostały zamknięte.',
     'Do you really want to close all tasks of this column?' => 'Na pewno chcesz zamknąć wszystkie zadania z tej kolumny?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadania z kolumny "%s" i toru "%s" zostaną zamknięte.',
-    'Close all tasks of this column' => 'Zamknij wszystkie zadania w tej kolumnie',
+    'Close all tasks in this column and this swimlane' => 'Zamknij wszystkie zadania w tej kolumnie',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Wtyczki obsługujące dodatkowe powiadomienia nie zostały zainstalowane. Dalej jednak możesz korzystać z standardowych powiadomień (sprawdź w ustawieniach Twojego profilu).',
     'My dashboard' => 'Mój dashboard',
     'My profile' => 'Mój profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Zaznacz wszystko',
     'Unselect All' => 'Odznacz wszystko',
     'Apply action' => 'Zastosuj akcję',
-    'Move selected tasks to another column' => 'Przenieś wybrane zadania do innej kolumny',
+    'Move selected tasks to another column or swimlane' => 'Przenieś wybrane zadania do innej kolumny',
     'Edit tasks in bulk' => 'Edytuj zadania grupowo',
     'Choose the properties that you would like to change for the selected tasks.' => 'Wybierz właściwość wskazanego zadania, które chciałbyś zmienić.',
     'Configure this project' => 'Skonfiguruj projekt',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Sortuj kolumnę po osobie przydzielonej do zadania (malejąco)',
     'Reorder this column by due date (ASC)' => 'Sortuj kolumnę po dacie zakończenia (rosnąco)',
     'Reorder this column by due date (DESC)' => 'Sortuj kolumnę po dacie zakończenia (malejąco)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s przeniósł zadanie nr %d "%s" do projektu "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Zadanie nr %d "%s" zostało przeniesione do projektu "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Przenieś zadanie do innej kolumny, kiedy data zakończenia jest oddalona o określoną liczbę dni od aktualnej daty',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
