@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rúpia indiana',
     'JPY - Japanese Yen' => 'JPY - Iene japonês',
     'NZD - New Zealand Dollar' => 'NZD - Dólar neozelandês',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Dinar sérvio',
     'CNY - Chinese Yuan' => 'CNY - Yuan Renminbi da China',
     'USD - US Dollar' => 'USD - Dólar norte-americano',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas as tarefas da coluna "%s" e da raia "%s" foram finalizadas com sucesso.',
     'Do you really want to close all tasks of this column?' => 'Você realmente deseja finalizar todas as tarefas desta coluna?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarefa(s) da coluna "%s" e da raia "%s" serão finalizadas.',
-    'Close all tasks of this column' => 'Finalizar todas as tarefas desta coluna',
+    'Close all tasks in this column and this swimlane' => 'Finalizar todas as tarefas desta coluna',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nenhum plugin registrou método de notificação de projeto. Você ainda pode definir notificações individuais em seu perfil de usuário.',
     'My dashboard' => 'Meu Painel de Controle',
     'My profile' => 'Meu perfil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Selecionar todos',
     'Unselect All' => 'Desmarcar todos',
     'Apply action' => 'Aplicar ação',
-    'Move selected tasks to another column' => 'Mover tarefas selecionadas para outra coluna',
+    'Move selected tasks to another column or swimlane' => 'Mover tarefas selecionadas para outra coluna',
     'Edit tasks in bulk' => 'Editar tarefas em massa',
     'Choose the properties that you would like to change for the selected tasks.' => 'Escolher as propriedades que deseja mudar para as tarefas selecionadas.',
     'Configure this project' => 'Configurar este projeto',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por designado (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data fim estimada (crescente)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data fim estimada (decrescente)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data fim estimada for menor que uma quantidade de dias',
@@ -1422,16 +1425,45 @@ return array(
     'Collapse vertically' => 'Contrair verticalmente',
     'Expand vertically' => 'Expandir verticalmente',
     'MXN - Mexican Peso' => 'Peso mexicano',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'Estimated vs actual time per column' => 'Tempo estimado vs tempo real por coluna',
+    'HUF - Hungarian Forint' => 'HUF - Florim húngaro',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
+    'You must select a file to upload as your avatar!' => 'Você deve selecionar um arquivo para enviar como seu avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O arquivo enviado não é uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são aceitos!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Definir data de vencimento automaticamente quando a tarefa sair de determinada coluna',
+    'No other projects found.' => 'Nenhum outro projeto encontrado.',
+    'Please choose a project you want to copy the tasks from.' => 'Por favor escolha o projeto de onde você deseja copiar as tarefas.',
+    'Import Tasks' => 'Importar Tarefas',
+    'Copy' => 'Copiar',
+    'Tasks copied successfully.' => 'Tarefas copiadas com sucesso.',
+    'Unable to copy tasks.' => 'Não foi possível copiar as tarefas.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Tema claro',
+    'Dark theme' => 'Tema escuro',
+    'Automatic theme - Sync with system' => 'Tema automático - Sincronizar com o sistema',
+    'Application managers or more' => 'Gerentes da aplicação ou mais',
+    'Administrators' => 'Administradores',
+    'Visibility:' => 'Visibilidade:',
+    'Standard users' => 'Usuários comuns',
+    'Visibility is required' => 'Visibilidade é obrigatória',
+    'The visibility should be an app role' => 'A visibilidade deve ser uma função da aplicação',
+    'Reply' => 'Responder',
+    '%s wrote: ' => '%s escreveu:',
+    'Number of visible tasks in this column and swimlane' => 'Número de tarefas visíveis nesta coluna e raia',
+    'Number of tasks in this swimlane' => 'Número de tarefas nesta raia',
+    'Unable to find another subtask in progress, you can close this window.' => 'Não foi possível encontrar outra subtarefa em progresso, você pode fechar esta janela.',
+    'This theme is invalid' => 'Esse tema não é válido',
+    'This role is invalid' => 'Essa função não é válida',
+    'This timezone is invalid' => 'Esse fuso horário não é válido',
+    'This language is invalid' => 'Esse idioma não é válido',
+    'This URL is invalid' => 'Essa URL não é válida',
+    'Date format invalid' => 'Formato de data inválido',
+    'Time format invalid' => 'Formato de tempo inválido',
+    'Invalid Mail transport' => 'Transportador de E-mail inválido',
+    'Color invalid' => 'Cor inválida',
+    'This value must be greater or equal to %d' => 'Esse valor deve ser maior ou igual a %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adicionar BOM ao início do arquivo (obrigatório para Microsoft Excel)',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
