@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rúpia Indiana',
     'JPY - Japanese Yen' => 'JPY - Iene Japonês',
     'NZD - New Zealand Dollar' => 'NZD - Dólar Neozelandês',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Dinar Sérvio',
     'CNY - Chinese Yuan' => 'CNY - Yuan Chinês',
     'USD - US Dollar' => 'USD - Dólar Norte-americano',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas as tarefas na coluna "%s" e na swimlane "%s" foram fechadas com successo.',
     'Do you really want to close all tasks of this column?' => 'Tem a certeza que quer fechar todas as tarefas nesta coluna?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarefa(s) na coluna "%s" e na swimlane "%s" serão fechadas.',
-    'Close all tasks of this column' => 'Fechar todas as tarefas nesta coluna',
+    'Close all tasks in this column and this swimlane' => 'Fechar todas as tarefas nesta coluna',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nenhum plugin tem registado um método de notificação do projeto. Pode continuar a configurar notificações individuais no seu perfil de utilizador.',
     'My dashboard' => 'Meu painel',
     'My profile' => 'Meu perfil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Selecionar Tudo',
     'Unselect All' => 'Desmarcar Tudo',
     'Apply action' => 'Aplicar ação',
-    'Move selected tasks to another column' => 'Mover tarefas selecionadas para outra coluna',
+    'Move selected tasks to another column or swimlane' => 'Mover tarefas selecionadas para outra coluna',
     'Edit tasks in bulk' => 'Editar tarefas em massa',
     'Choose the properties that you would like to change for the selected tasks.' => 'Escolha as propriedades que pretente modificar nas tarefas selecionadas.',
     'Configure this project' => 'Configurar este projeto',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por assignado (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data de vencimento (ASC)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data de vencimento (DESC)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data de vencimento é menos que um certo numero de dias',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
