@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupie indiană',
     'JPY - Japanese Yen' => 'JPY - Yen japonez',
     'NZD - New Zealand Dollar' => 'NZD - Dolar neo-zeelandez',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Dinar sârbesc',
     'CNY - Chinese Yuan' => 'CNY - Yuan chinez',
     'USD - US Dollar' => 'USD - Dolar american',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Toate sarcinile coloanei "%s" si a culoarului "%s" au fost închise.',
     'Do you really want to close all tasks of this column?' => 'Vrei să închizi toate sarcinile acestei coloane?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d sarcini în coloana "%s" si culoarul "%s" vor fi închise.',
-    'Close all tasks of this column' => 'Închide toate sarcinile acestei coloane',
+    'Close all tasks in this column and this swimlane' => 'Închide toate sarcinile acestei coloane',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nici o extensie nu a înregistrat o metodă de notificare a proiectelor. Mai poți însă configura notificări individuale în profilul tău de utilizator.',
     'My dashboard' => 'Bordul meu',
     'My profile' => 'Profilul meu',
@@ -1377,7 +1378,7 @@ return array(
     // 'Select All' => '',
     // 'Unselect All' => '',
     // 'Apply action' => '',
-    // 'Move selected tasks to another column' => '',
+    // 'Move selected tasks to another column or swimlane' => '',
     // 'Edit tasks in bulk' => '',
     // 'Choose the properties that you would like to change for the selected tasks.' => '',
     // 'Configure this project' => '',
@@ -1399,6 +1400,8 @@ return array(
     // 'Reorder this column by assignee (Z-A)' => '',
     // 'Reorder this column by due date (ASC)' => '',
     // 'Reorder this column by due date (DESC)' => '',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     // '%s moved the task #%d "%s" to the project "%s"' => '',
     // 'Task #%d "%s" has been moved to the project "%s"' => '',
     // 'Move the task to another column when the due date is less than a certain number of days' => '',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
