@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indijski rupi',
     'JPY - Japanese Yen' => 'JPY - Japanski jen',
     'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Srpski dinar',
     'CNY - Chinese Yuan' => 'CNY - Kineski jen',
     'USD - US Dollar' => 'USD - Američki dolar',
@@ -590,13 +591,13 @@ return array(
     'Day(s)' => 'Dan/i',
     'Existing due date' => 'Postojeći rok završetka',
     'Factor to calculate new due date: ' => 'Faktor za računanje novog roka završetka: ',
-    'Month(s)' => 'Mjesec(i)',
+    'Month(s)' => 'Mesec(i)',
     'This task has been created by: ' => 'Ovaj zadatak je napravio: ',
     'Recurrent task has been generated:' => 'Ponavljajući zadatak je napravio:',
     'Timeframe to calculate new due date: ' => 'Vremenski okvir za računanje novog roka završetka:',
     'Trigger to generate recurrent task: ' => 'Okidač za pravljenje ponavljajućeg zadatka',
     'When task is closed' => 'Kada je zadatak zatvoren',
-    'When task is moved from first column' => 'Kada je zadatak premješten iz prve kolone',
+    'When task is moved from first column' => 'Kada je zadatak premešten iz prve kolone',
     'When task is moved to last column' => 'Kada je zadatak premešten u poslednju kolonu',
     'Year(s)' => 'Godina/e',
     'Project settings' => 'Postavke projekta',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Svi zadaci kolone "%s" i staze "%s" uspešno su zatvoreni.',
     'Do you really want to close all tasks of this column?' => 'Da li zaista želite da zatvorite sve zadatke ove kolone?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadatak/zadaci u koloni "%s" i stazi "%s" će biti zatvoreni.',
-    'Close all tasks of this column' => 'Zatvori sve zadatke ove kolone',
+    'Close all tasks in this column and this swimlane' => 'Zatvori sve zadatke u ovoj koloni i ovoj stazi',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nijedan dodatak nije registrovao metodu obaveštavanja o projektu. U korisničkom profilu i dalje možete da konfigurišete pojedinačna obaveštenja.',
     'My dashboard' => 'Moja komandna tabla',
     'My profile' => 'Moj profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Izaberi sve',
     'Unselect All' => 'Poništi sve',
     'Apply action' => 'Primeni akciju',
-    'Move selected tasks to another column' => 'Pomerei odabrani zadatak u neku drugu kolonu',
+    'Move selected tasks to another column or swimlane' => 'Pomerei odabrani zadatak u neku drugu kolonu ili stazu',
     'Edit tasks in bulk' => 'Masovno uređivanje zadataka',
     'Choose the properties that you would like to change for the selected tasks.' => 'Izaberite svojstva koja biste želeli da promenite za izabrane zadatke.',
     'Configure this project' => 'Konfigurišite ovaj projekat',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Promenite redosled ove kolone prema izvršiocu (Ž-A)',
     'Reorder this column by due date (ASC)' => 'Promenite redosled ove kolone prema roku završetka (UZLAZNO)',
     'Reorder this column by due date (DESC)' => 'Promenite redosled ove kolone prema roku završetka (SILAZNO)',
+    'Reorder this column by id (ASC)' => 'Promenite redosled ove kolone prema ID-u (UZLAZNO)',
+    'Reorder this column by id (DESC)' => 'Promenite redosled ove kolone prema ID-u (SILAZNO)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s je pomerio/la zadatak #%d "%s" u projekat "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premešten u projekat "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pomeri zadatak u neku drugu kolonu kada je datum roka završetka kraći od određenog broja dana',
@@ -1421,17 +1424,46 @@ return array(
     'Comment' => 'Komentar',
     'Collapse vertically' => 'Skupi vertikalno',
     'Expand vertically' => 'Raširi vertikalno',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'MXN - Mexican Peso' => 'MXN - Meksički pezos',
+    'Estimated vs actual time per column' => 'Procenjeno vreme naspram stvarnog vremena po koloni',
+    'HUF - Hungarian Forint' => 'HUF - Mađarska forinta',
     'XBT - Bitcoin' => 'XBT - Bitkoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
+    'You must select a file to upload as your avatar!' => 'Morate izabrati datoteku koju ćete postaviti kao avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste otpremili nije validna slika! (Dozvoljeni su samo *.gif, *.jpg, *.jpeg i *.png formati!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavite rok završetka kada se zadatak premesti iz određene kolone',
+    'No other projects found.' => 'Nisu pronađeni drugi projekti.',
+    'Please choose a project you want to copy the tasks from.' => 'Molimo izaberite projekat iz kojeg želite da kopirate zadatke.',
+    'Import Tasks' => 'Uvoz zadatka',
+    'Copy' => 'Kopiraj',
+    'Tasks copied successfully.' => 'Zadaci su uspešno iskopirani.',
+    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Svetla tema',
+    'Dark theme' => 'Tamna tema',
+    'Automatic theme - Sync with system' => 'Automatska tema - sinhronizacija sa sistemom',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
