@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indiska rupier',
     'JPY - Japanese Yen' => 'JPY - Japanska yen',
     'NZD - New Zealand Dollar' => 'NZD - Nya Zeeländska dollar',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'RSD - Serbiska dinarer',
     'CNY - Chinese Yuan' => 'CNY - Kinesisk yuan',
     'USD - US Dollar' => 'USD - Amerikanska dollar',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alla uppgifter i kolumnen "%s" samt simbanan "%s" har stängts.',
     'Do you really want to close all tasks of this column?' => 'Vill du verkligen stänga alla uppgifter i denna kolumn?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d uppgift(er) i kolumnen "%s" och simbanan "%s" kommer stängas.',
-    'Close all tasks of this column' => 'Stäng alla uppgifter i denna kolumn',
+    'Close all tasks in this column and this swimlane' => 'Stäng alla uppgifter i denna kolumn',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Inget insticksprogram har registrerat notifieringsmetod för projektet. Du kan fortfarande konfigurera personliga notifikationer i din användarprofil.',
     'My dashboard' => 'Min översiktspanel',
     'My profile' => 'Min profil',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Välj alla',
     'Unselect All' => 'Avmarkera alla',
     'Apply action' => 'Genomför åtgärd',
-    'Move selected tasks to another column' => 'Flytta markerade uppgifter till en annan kolumn',
+    'Move selected tasks to another column or swimlane' => 'Flytta markerade uppgifter till en annan kolumn',
     'Edit tasks in bulk' => 'Massredigera uppgifer',
     'Choose the properties that you would like to change for the selected tasks.' => 'Välj vilka egenskaper som du vill ändra för de valda uppgifterna.',
     'Configure this project' => 'Konfigurera projekt',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Ändra ordning i denna kolumnen enligt tilldelning (Z-A)',
     'Reorder this column by due date (ASC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (stigande)',
     'Reorder this column by due date (DESC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (fallande)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s flyttade uppgift #%d "%s" till projektet "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Uppgift #%d "%s" har flyttats till projektet "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Flytta uppgiften till en annan kolumn när förfallodatum är närmare än ett visst antal dagar',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
