@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Hint Rupesi',
     'JPY - Japanese Yen' => 'JPY - Japon Yeni',
     'NZD - New Zealand Dollar' => 'NZD - Yeni Zelanda Doları',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => 'Sırp Dinarı',
     'CNY - Chinese Yuan' => 'Çin Yuanı',
     'USD - US Dollar' => 'USD Amerikan Doları',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '"%s" sütunu ve "%s" kulvarındaki tüm görevler başarıyla kapatıldı.',
     'Do you really want to close all tasks of this column?' => 'Bu sütundaki tüm görevleri kapatmak istediğinize emin misiniz?',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '"%s" sütunu ve "%s" kulvarındaki %d görev kapatılacak.',
-    'Close all tasks of this column' => 'Bu sütundaki tüm görevleri kapat',
+    'Close all tasks in this column and this swimlane' => 'Bu sütundaki tüm görevleri kapat',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Proje bildirimleri için hiçbir plugin kaydedilmedi. Yine de profil sayfanızdan bildirim ayarları yapabilirsiniz.',
     'My dashboard' => 'Panom',
     'My profile' => 'Profilim',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => 'Tümünü Seç',
     'Unselect All' => 'Tüm Seçimi Kaldır',
     'Apply action' => 'Komutu Uygula',
-    'Move selected tasks to another column' => 'Seçili görevleri başka kolona taşı',
+    'Move selected tasks to another column or swimlane' => 'Seçili görevleri başka kolona taşı',
     'Edit tasks in bulk' => 'Görevleri toplu olarak güncelle',
     'Choose the properties that you would like to change for the selected tasks.' => 'Seçili görevler için değiştirilecek özellikleri seç',
     'Configure this project' => 'Proje Ayarları',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Kolonu atanana göre azalan sırala (Z-A)',
     'Reorder this column by due date (ASC)' => 'Kolonu hedef tarihe göre artan sırala',
     'Reorder this column by due date (DESC)' => 'Kolonu hedef tarihe göre azalan sırala',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s görevi taşıdı #%d "%s" "%s" projesine',
     'Task #%d "%s" has been moved to the project "%s"' => 'Görev #%d "%s" tarafından "%s" projesine taşındı',
     'Move the task to another column when the due date is less than a certain number of days' => 'Hedef tarihe belirli bir gün sayısından az kaldığında görevi başka kolona taşı',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
