@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => '印度卢比',
     'JPY - Japanese Yen' => '日元',
     'NZD - New Zealand Dollar' => '新西兰元',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => '第纳尔',
     'CNY - Chinese Yuan' => '人民币',
     'USD - US Dollar' => '美元',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '任务栏 "%s" 和 泳道 "%s" 下的所有任务已关闭',
     'Do you really want to close all tasks of this column?' => '你确定要关闭此任务栏下的所有任务？',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '任务栏 "%s" 和 泳道 "%s" 下 %d 条任务将被关闭。',
-    'Close all tasks of this column' => '关闭此任务栏下的所有任务',
+    'Close all tasks in this column and this swimlane' => '关闭此任务栏下的所有任务',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '没有插件注册到项目通知接口，你仍然可以在你个人设置里启用单独的通知',
     'My dashboard' => '我的看板',
     'My profile' => '个人信息',
@@ -1377,7 +1378,7 @@ return array(
     'Select All' => '全选',
     'Unselect All' => '取消',
     'Apply action' => '应用动作',
-    'Move selected tasks to another column' => '移动选中任务到另一列',
+    'Move selected tasks to another column or swimlane' => '移动选中任务到另一列',
     'Edit tasks in bulk' => '批量编辑任务',
     'Choose the properties that you would like to change for the selected tasks.' => '选择你想要批量编辑的任务属性。',
     'Configure this project' => '项目配置',
@@ -1399,6 +1400,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => '按指派重排(Z-A)',
     'Reorder this column by due date (ASC)' => '按逾期时间重排(升序)',
     'Reorder this column by due date (DESC)' => '按逾期时间重排(降序)',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     '%s moved the task #%d "%s" to the project "%s"' => '%s 已将任务 #%d "%s" 移动到项目"%s" ',
     'Task #%d "%s" has been moved to the project "%s"' => '任务 #%d "%s" 已被移动到项目 "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => '当任务即将在指定天数内超期时移动到另一栏',
@@ -1428,10 +1431,39 @@ return array(
     'You must select a file to upload as your avatar!' => '你必须选择一张图片作为你的头像',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '你所上传的文件不是有效图像！(只有*.gif, *.jpg, *.jpeg and *.png才被允许！)',
     'Automatically set the due date when the task is moved away from a specific column' => '当任务离开指定栏目时自动设置到期时间',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
+    'No other projects found.' => '未找到其它项目。',
+    'Please choose a project you want to copy the tasks from.' => '请选择将要复制的任务所属的项目。',
+    'Import Tasks' => '引入任务',
+    'Copy' => '复制',
+    'Tasks copied successfully.' => '任务复制成功。',
+    'Unable to copy tasks.' => '无法复制任务。',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
