@@ -525,6 +525,7 @@ return array(
     'INR - Indian Rupee' => '印度盧比',
     'JPY - Japanese Yen' => '日元',
     'NZD - New Zealand Dollar' => '紐西蘭元',
+    // 'PEN - Peruvian Sol' => '',
     'RSD - Serbian dinar' => '第納爾',
     'CNY - Chinese Yuan' => '人民幣',
     'USD - US Dollar' => '美元',
@@ -899,7 +900,7 @@ return array(
     'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '任務欄 "%s" 和 里程碑 "%s" 下的所有任務已關閉',
     'Do you really want to close all tasks of this column?' => '你確定要關閉此任務欄下的所有任務？',
     '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '任務欄 "%s" 和 里程碑 "%s" 下 %d 任務將被關閉。',
-    'Close all tasks of this column' => '關閉此任務欄下的所有任務',
+    'Close all tasks in this column and this swimlane' => '關閉此任務欄下的所有任務',
     'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '没有插件註冊到專案通知API，你仍然可以在你個人設定裡啟用單獨的通知',
     'My dashboard' => '我的儀表板',
     'My profile' => '我的個人訊息',
@@ -1377,7 +1378,7 @@ return array(
     // 'Select All' => '',
     // 'Unselect All' => '',
     // 'Apply action' => '',
-    // 'Move selected tasks to another column' => '',
+    // 'Move selected tasks to another column or swimlane' => '',
     // 'Edit tasks in bulk' => '',
     // 'Choose the properties that you would like to change for the selected tasks.' => '',
     // 'Configure this project' => '',
@@ -1399,6 +1400,8 @@ return array(
     // 'Reorder this column by assignee (Z-A)' => '',
     // 'Reorder this column by due date (ASC)' => '',
     // 'Reorder this column by due date (DESC)' => '',
+    // 'Reorder this column by id (ASC)' => '',
+    // 'Reorder this column by id (DESC)' => '',
     // '%s moved the task #%d "%s" to the project "%s"' => '',
     // 'Task #%d "%s" has been moved to the project "%s"' => '',
     // 'Move the task to another column when the due date is less than a certain number of days' => '',
@@ -1434,4 +1437,33 @@ return array(
     // 'Copy' => '',
     // 'Tasks copied successfully.' => '',
     // 'Unable to copy tasks.' => '',
+    // 'Theme' => '',
+    // 'Theme:' => '',
+    // 'Light theme' => '',
+    // 'Dark theme' => '',
+    // 'Automatic theme - Sync with system' => '',
+    // 'Application managers or more' => '',
+    // 'Administrators' => '',
+    // 'Visibility:' => '',
+    // 'Standard users' => '',
+    // 'Visibility is required' => '',
+    // 'The visibility should be an app role' => '',
+    // 'Reply' => '',
+    // '%s wrote: ' => '',
+    // 'Number of visible tasks in this column and swimlane' => '',
+    // 'Number of tasks in this swimlane' => '',
+    // 'Unable to find another subtask in progress, you can close this window.' => '',
+    // 'This theme is invalid' => '',
+    // 'This role is invalid' => '',
+    // 'This timezone is invalid' => '',
+    // 'This language is invalid' => '',
+    // 'This URL is invalid' => '',
+    // 'Date format invalid' => '',
+    // 'Time format invalid' => '',
+    // 'Invalid Mail transport' => '',
+    // 'Color invalid' => '',
+    // 'This value must be greater or equal to %d' => '',
+    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
+    // 'Just add these tag(s)' => '',
+    // 'Remove internal link(s)' => '',
 );
