@@ -8,7 +8,18 @@ use PDO;
 use Kanboard\Core\Security\Token;
 use Kanboard\Core\Security\Role;
 
-const VERSION = 1;
+
+const VERSION = 3;
+
+function version_3(PDO $pdo)
+{
+    $pdo->exec("ALTER TABLE dbo.comments ADD visibility nvarchar(25) DEFAULT N'".Role::APP_USER."' NOT NULL");
+}
+
+function version_2(PDO $pdo)
+{
+  $pdo->exec("ALTER TABLE dbo.users ADD theme nvarchar(50) DEFAULT N'light' NOT NULL");
+}
 
 function version_1(PDO $pdo)
 {
